@@ -19,50 +19,40 @@ from .utils import (contour_to_edges_endpoints,
                     flatten)
 
 
-def from_contour(contour: Contour,
-                 *,
-                 context: Context) -> Box:
+def from_contour(contour: Contour, context: Context) -> Box:
     """
     Builds box from contour.
     """
-    return from_points(contour.vertices,
-                       context=context)
+    return from_points(contour.vertices, context)
 
 
-def from_segments(segments: Sequence[Segment],
-                  *,
-                  context: Context) -> Box:
+def from_segments(segments: Sequence[Segment], context: Context) -> Box:
     """
     Builds box from multisegment.
     """
     return from_points(flatten((segment.start, segment.end)
-                               for segment in segments),
-                       context=context)
+                               for segment in segments), context)
 
 
-def from_polygons(polygons: Sequence[Polygon],
-                  *,
-                  context: Context) -> Box:
+def from_polygons(polygons: Sequence[Polygon], context: Context) -> Box:
     """
     Builds box from multipolygon.
     """
     return from_points(flatten(polygon.border.vertices
                                for polygon in polygons),
-                       context=context)
+                       context)
 
 
 def from_multiregion(multiregion: Multiregion,
-                     *,
                      context: Context) -> Box:
     """
     Builds box from multiregion.
     """
     return from_points(flatten(region.vertices for region in multiregion),
-                       context=context)
+                       context)
 
 
 def from_points(points: Iterable[Point],
-                *,
                 context: Context) -> Box:
     """
     Builds box from points.
@@ -84,13 +74,12 @@ def from_points(points: Iterable[Point],
 
 
 def from_segment(segment: Segment,
-                 *,
                  context: Context) -> Box:
     """
     Builds box from segment.
     """
     return from_points((segment.start, segment.end),
-                       context=context)
+                       context)
 
 
 def disjoint_with(left: Box, right: Box) -> bool:
@@ -255,31 +244,29 @@ def within_of(test: Box, goal: Box) -> bool:
 def intersects_with_segment(box: Box,
                             start: Point,
                             end: Point,
-                            *,
                             context: Context) -> bool:
     """
     Checks if the box intersects the segment.
     """
     segment_box = from_points((start, end),
-                              context=context)
+                              context)
     return (intersects_with(segment_box, box)
             and (is_subset_of(segment_box, box)
                  or any(context.segments_relation(edge_start, edge_end, start,
                                                   end) is not Relation.DISJOINT
                         for edge_start, edge_end
                         in to_edges_endpoints(box,
-                                              context=context))))
+                                              context))))
 
 
 def coupled_with_segment(box: Box,
                          segment: Segment,
-                         *,
                          context: Context) -> bool:
     """
     Checks if the box intersects the segment at more than one point.
     """
     segment_box = from_segment(segment,
-                               context=context)
+                               context)
     return (coupled_with(segment_box, box)
             and (is_subset_of(segment_box, box)
                  or any(context.segments_relation(edge_start, edge_end,
@@ -287,12 +274,11 @@ def coupled_with_segment(box: Box,
                         not in (Relation.TOUCH, Relation.DISJOINT)
                         for edge_start, edge_end
                         in to_edges_endpoints(box,
-                                              context=context))))
+                                              context))))
 
 
 def is_subset_of_region(box: Box,
                         border: Contour,
-                        *,
                         context: Context) -> bool:
     """
     Checks if the box is the subset of the region.
@@ -301,54 +287,51 @@ def is_subset_of_region(box: Box,
                                                       Relation.ENCLOSED,
                                                       Relation.WITHIN)
                for segment in to_edges(box,
-                                       context=context))
+                                       context))
 
 
 def within_of_region(box: Box,
                      border: Contour,
-                     *,
                      context: Context) -> bool:
     """
     Checks if the box is contained in an interior of the region.
     """
     return (all(point_in_region(vertex, border) is Relation.WITHIN
                 for vertex in to_vertices(box,
-                                          context=context))
+                                          context))
             and all(context.segments_relation(edge_start, edge_end,
                                               border_edge_start,
                                               border_edge_end)
                     is Relation.DISJOINT
                     for edge_start, edge_end
                     in to_edges_endpoints(box,
-                                          context=context)
+                                          context)
                     for border_edge_start, border_edge_end
                     in contour_to_edges_endpoints(border)))
 
 
 def is_subset_of_multiregion(box: Box,
                              multiregion: Multiregion,
-                             *,
                              context: Context) -> bool:
     """
     Checks if the box is the subset of the multiregion.
     """
     return any(is_subset_of(box, from_contour(region,
-                                              context=context))
+                                              context))
                and is_subset_of_region(box, region,
-                                       context=context)
+                                       context)
                for region in multiregion)
 
 
 def intersects_with_polygon(box: Box,
                             polygon: Polygon,
-                            *,
                             context: Context) -> bool:
     """
     Checks if the box intersects the polygon.
     """
     border = polygon.border
     polygon_box = from_contour(border,
-                               context=context)
+                               context)
     if not intersects_with(polygon_box, box):
         return False
     elif (is_subset_of(polygon_box, box)
@@ -356,7 +339,7 @@ def intersects_with_polygon(box: Box,
         return True
     relations = [point_in_region(vertex, border)
                  for vertex in to_vertices(box,
-                                           context=context)]
+                                           context)]
     if (within_of(box, polygon_box)
             and all(relation is Relation.WITHIN for relation in relations)
             and all(context.segments_relation(edge_start, edge_end,
@@ -365,33 +348,32 @@ def intersects_with_polygon(box: Box,
                     is Relation.DISJOINT
                     for edge_start, edge_end
                     in to_edges_endpoints(box,
-                                          context=context)
+                                          context)
                     for border_edge_start, border_edge_end
                     in contour_to_edges_endpoints(border))):
         return not any(within_of(box, from_contour(hole,
-                                                   context=context))
+                                                   context))
                        and within_of_region(box, hole,
-                                            context=context)
+                                            context)
                        for hole in polygon.holes)
     else:
         return (any(relation is not Relation.DISJOINT
                     for relation in relations)
                 or any(intersects_with_segment(box, border_edge_start,
                                                border_edge_end,
-                                               context=context)
+                                               context)
                        for border_edge_start, border_edge_end
                        in contour_to_edges_endpoints(border)))
 
 
 def intersects_with_region(box: Box,
                            region: Region,
-                           *,
                            context: Context) -> bool:
     """
     Checks if the box intersects the region.
     """
     region_box = from_contour(region,
-                              context=context)
+                              context)
     return (intersects_with(region_box, box)
             and (is_subset_of(region_box, box)
                  or any(contains_point(box, vertex)
@@ -399,24 +381,23 @@ def intersects_with_region(box: Box,
                  or any(point_in_region(vertex, region)
                         is not Relation.DISJOINT
                         for vertex in to_vertices(box,
-                                                  context=context))
+                                                  context))
                  or any(intersects_with_segment(box, border_edge_start,
                                                 border_edge_end,
-                                                context=context)
+                                                context)
                         for border_edge_start, border_edge_end in
                         contour_to_edges_endpoints(region))))
 
 
 def coupled_with_polygon(box: Box,
                          polygon: Polygon,
-                         *,
                          context: Context) -> bool:
     """
     Checks if the box intersects the polygon in continuous points set.
     """
     border = polygon.border
     polygon_box = from_contour(border,
-                               context=context)
+                               context)
     if not coupled_with(polygon_box, box):
         return False
     elif (is_subset_of(polygon_box, box)
@@ -424,35 +405,34 @@ def coupled_with_polygon(box: Box,
         return True
     relations = [point_in_region(vertex, border)
                  for vertex in to_vertices(box,
-                                           context=context)]
+                                           context)]
     if any(relation is Relation.WITHIN for relation in relations):
         return (not all(relation is Relation.WITHIN for relation in relations)
                 or not is_subset_of_multiregion(box, polygon.holes,
-                                                context=context))
+                                                context))
     else:
         return (not is_subset_of_multiregion(box, polygon.holes,
-                                             context=context)
+                                             context)
                 if (is_subset_of(box, polygon_box)
                     and is_subset_of_region(box, border,
-                                            context=context))
+                                            context))
                 else any(segment_in_contour(segment, border)
                          is Relation.OVERLAP
                          or segment_in_region(segment, border)
                          in (Relation.CROSS, Relation.COMPONENT,
                              Relation.ENCLOSED)
                          for segment in to_edges(box,
-                                                 context=context)))
+                                                 context)))
 
 
 def coupled_with_region(box: Box,
                         region: Region,
-                        *,
                         context: Context) -> bool:
     """
     Checks if the box intersects the region in continuous points set.
     """
     region_box = from_contour(region,
-                              context=context)
+                              context)
     if not coupled_with(region_box, box):
         return False
     elif (is_subset_of(region_box, box)
@@ -460,17 +440,17 @@ def coupled_with_region(box: Box,
         return True
     return (any(point_in_region(vertex, region) is Relation.WITHIN
                 for vertex in to_vertices(box,
-                                          context=context))
+                                          context))
             or is_subset_of(box, region_box)
             and is_subset_of_region(box, region,
-                                    context=context)
+                                    context)
             or any(segment_in_contour(segment, region)
                    is Relation.OVERLAP
                    or segment_in_region(segment, region)
                    in (Relation.CROSS, Relation.COMPONENT,
                        Relation.ENCLOSED)
                    for segment in to_edges(box,
-                                           context=context)))
+                                           context)))
 
 
 def contains_point(box: Box, point: Point) -> bool:
@@ -483,7 +463,6 @@ def covers_point(box: Box, point: Point) -> bool:
 
 
 def to_vertices(box: Box,
-                *,
                 context: Context) -> Sequence[Point]:
     point_cls = context.point_cls
     return (point_cls(box.min_x, box.min_y), point_cls(box.max_x, box.min_y),
@@ -491,7 +470,6 @@ def to_vertices(box: Box,
 
 
 def to_edges_endpoints(box: Box,
-                       *,
                        context: Context) -> Sequence[SegmentEndpoints]:
     point_cls = context.point_cls
     return ((point_cls(box.min_x, box.min_y), point_cls(box.max_x, box.min_y)),
@@ -501,7 +479,6 @@ def to_edges_endpoints(box: Box,
 
 
 def to_edges(box: Box,
-             *,
              context: Context) -> Sequence[Segment]:
     point_cls, segment_cls = context.point_cls, context.segment_cls
     return (segment_cls(point_cls(box.min_x, box.min_y),
@@ -516,59 +493,53 @@ def to_edges(box: Box,
 
 def to_intersecting_segments(box: Box,
                              segments: Sequence[Segment],
-                             *,
                              context: Context) -> Sequence[Segment]:
     return [segment
             for segment in segments
             if intersects_with_segment(box, segment.start, segment.end,
-                                       context=context)]
+                                       context)]
 
 
 def to_coupled_segments(box: Box,
                         segments: Sequence[Segment],
-                        *,
                         context: Context) -> Sequence[Segment]:
     return [segment
             for segment in segments
             if coupled_with_segment(box, segment,
-                                    context=context)]
+                                    context)]
 
 
 def to_intersecting_polygons(box: Box,
                              polygons: Sequence[Polygon],
-                             *,
                              context: Context) -> Sequence[Polygon]:
     return [polygon
             for polygon in polygons
             if intersects_with_polygon(box, polygon,
-                                       context=context)]
+                                       context)]
 
 
 def to_intersecting_regions(box: Box,
                             multiregion: Multiregion,
-                            *,
                             context: Context) -> Multiregion:
     return [region
             for region in multiregion
             if intersects_with_region(box, region,
-                                      context=context)]
+                                      context)]
 
 
 def to_coupled_polygons(box: Box,
                         polygons: Sequence[Polygon],
-                        *,
                         context: Context) -> Sequence[Polygon]:
     return [polygon
             for polygon in polygons
             if coupled_with_polygon(box, polygon,
-                                    context=context)]
+                                    context)]
 
 
 def to_coupled_regions(box: Box,
                        multiregion: Multiregion,
-                       *,
                        context: Context) -> Multiregion:
     return [region
             for region in multiregion
             if coupled_with_region(box, region,
-                                   context=context)]
+                                   context)]
